@@ -1,7 +1,9 @@
 """Abstraction layer to construct a workflow as an airflow DAG."""
 import json
+import logging
 from os import environ
 from pathlib import Path
+from typing import List
 from typing import Optional
 from typing import Union
 
@@ -39,6 +41,7 @@ class Workflow:
         process_category: str,
         process_name: str,
         workflow_package: str,
+        tags: Optional[List[str]] = None,
         workflow_version: Optional[str] = None,
     ):
         """
@@ -50,6 +53,7 @@ class Workflow:
         process_name: Name for the process the workflow executes e.g. algorithm name
         workflow_package: The string representing the dot notation location of the
           workflow definition. e.g. __package__
+        tags: tags to be used in airflow's UI when searching for dags
         workflow_version: Version of the workflow being deployed.  Typically populated by the CI/CD
           build process.
 
@@ -59,13 +63,23 @@ class Workflow:
         self.process_name = process_name
         self.workflow_name = f"{self.process_category}_{self.process_name}"
         self.workflow_version = workflow_version or environ.get("BUILD_VERSION", "dev")
+        self.tags = tags or []
         self._dag_name = f"{self.workflow_name}_{self.workflow_version}"
         self._dag = self._initialize_local_dag()
         self.nodes = []
 
     @property
     def _dag_tags(self) -> str:
-        tags = [self.process_category, self.process_name, self.workflow_version]
+        """
+        Return the list of dag tags to be used in Airflow's UI.
+
+        Equal to the list of supplied tags plus the workflow version.
+        """
+        if isinstance(self.tags, str):
+            self.tags = [self.tags]
+        tags = self.tags + [self.workflow_version]
+        # Make sure there are no duplicate tags
+        tags = list(set(tags))
         return json.dumps(tags)
 
     @property
